/*
 * [CrazyQuilt.java]
 *
 * Summary: Draws Quilt of random colours.
 *
 * Copyright: (c) 2012-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2012-12-25 initial version.
 */
package com.mindprod.connectors;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Polygon;
import java.util.Random;

/**
 * Draws Quilt of random colours.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2012-12-25 initial version.
 * @since 2012-12-25
 */
class CrazyQuilt extends ConnectorPanel
    {
    private static final Color OUTLINE_COLOR = Color.BLACK;

    private static final Random wheel = new Random();

    /**
     * thickness of the outline
     */
    private final int lineWidth;

    /**
     * overal dimension of entire image
     */
    private final int size;

    /**
     * half the overall dimension of the contained small squares.
     */
    private final int squareRadius;

    /**
     * Draw a quilty of randomly coloured and placed squares
     *
     * @param overallSize in pixels e.g. 32 .. 256
     * @param squareSize  of small squares in pixels 5 or 10
     * @param lineWidth   width in pixels of outlines of small and over all image 2..5
     */
    CrazyQuilt( final int overallSize, final int squareSize, final int lineWidth )
        {
        super( overallSize, overallSize );
        this.size = overallSize;
        this.squareRadius = squareSize / 2;
        this.lineWidth = lineWidth;
        }

    /**
     * draw random squares at random positions outlined.
     *
     * @param g where to paint
     */
    public void paintComponent( Graphics g )
        {
        super.paintComponent( g );
        final Graphics2D g2d = ( Graphics2D ) g;
        g2d.setColor( Color.BLACK );
        g2d.fillRect( 0, 0, size - 1, size - 1 );
        for ( int i = 0; i < 2000; i++ )
            {
            final Polygon outline = new Polygon();
            int x = wheel.nextInt( size );
            int y = wheel.nextInt( size );
            outline.addPoint( x - squareRadius, y - squareRadius );
            outline.addPoint( x - squareRadius, y + squareRadius );
            outline.addPoint( x + squareRadius, y + squareRadius );
            outline.addPoint( x + squareRadius, y - squareRadius );
            Color fillColor = new Color( wheel.nextInt( 256 * 256 * 256 ) );
            g2d.setColor( fillColor );
            g2d.fillPolygon( outline );
            g2d.setColor( OUTLINE_COLOR );
            g2d.setStroke( new BasicStroke( lineWidth ) );
            g2d.drawPolygon( outline );
            }
        // touch up the frame outline.
        g2d.setColor( Color.BLACK );
        final Polygon outline = new Polygon();
        outline.addPoint( 0, 0 );
        outline.addPoint( size - 1, 0 );
        outline.addPoint( size - 1, size - 1 );
        outline.addPoint( 0, size - 1 );
        g2d.setColor( OUTLINE_COLOR );
        g2d.setStroke( new BasicStroke( lineWidth ) );
        g2d.drawPolygon( outline );
        }
    }
