/*
 * [RJ11Female.java]
 *
 * Summary: draw RJ11Female.
 *
 * Copyright: (c) 2011-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2011-01-29 initial version.
 */
package com.mindprod.connectors;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Polygon;
import java.awt.Rectangle;
import java.awt.Shape;

/**
 * draw RJ11Female.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2011-01-29 initial version.
 * @since 2011-01-29
 */
class RJ11Female extends ConnectorPanel
    {
    private static final int CONTACT_LENGTH = 265;

    private static final int CONTACT_WIDTH = 40;

    private static final int FIRST_PIN = 150;

    private static final int H_STEP = 167;

    private static final int INSET = 10;

    private static final int INTER_PIN_SPACING = 140;

    private static final int LINER = 10;

    private static final int V_STEP = 200;

    /**
     * improved blue
     */
    private static final Color BLUE = new Color( 0x1e90ff );

    /**
     * improved green
     */
    private static final Color GREEN = new Color( 0x32cd32 );

    RJ11Female()
        {
        super( 1000, 910 );
        }

    /**
     * draw one pin
     *
     * @param g2d       graphics context
     * @param pinNumber pin number 1 to 8
     * @param color     What colour to draw the pin
     */
    private static void drawPin( Graphics2D g2d, int pinNumber, Color color )
        {
        g2d.setColor( color );
        int x = ( pinNumber - 1 ) * INTER_PIN_SPACING + FIRST_PIN;
        Rectangle pinOutline = new Rectangle( x - CONTACT_WIDTH / 2, INSET, CONTACT_WIDTH, CONTACT_LENGTH - INSET );
        g2d.fill( pinOutline );
        g2d.setStroke( new BasicStroke( LINER ) );
        g2d.setColor( OUTLINE_COLOR );
        g2d.draw( pinOutline );
        }

    /**
     * draw a RJ11Female
     *
     * @param g where to paint
     */
    public void paintComponent( Graphics g )
        {
        super.paintComponent( g );
        final Graphics2D g2d = ( Graphics2D ) g;
        final int xCenter = 500;
        final int xRight = 1000;
        final int yCenter = 500;
        //  whole stepped connector
        g2d.setColor( HOLE_COLOR );
        Shape rj11Outline = new Polygon( new int[] {
                INSET,
                INSET,
                H_STEP,
                H_STEP,
                H_STEP * 2,
                H_STEP * 2,
                xRight - H_STEP * 2,
                xRight - H_STEP * 2,
                xRight - H_STEP,
                xRight - H_STEP,
                xRight - INSET,
                xRight - INSET },
                new int[] {
                        INSET,
                        yCenter,
                        yCenter,
                        yCenter + V_STEP,
                        yCenter + V_STEP,
                        yCenter + V_STEP * 2,
                        yCenter + V_STEP * 2,
                        yCenter + V_STEP,
                        yCenter + V_STEP,
                        yCenter,
                        yCenter,
                        INSET }
                , 12
        );
        g2d.fill( rj11Outline );
        g2d.setStroke( new BasicStroke( LINER ) );
        g2d.setColor( OUTLINE_COLOR );
        g2d.draw( rj11Outline );
        g2d.setFont( new Font( "Dialog", Font.PLAIN, 170 ) );
        g2d.setColor( OUTLINE_COLOR );
        drawCenteredString( g2d, "1 2 3 4 5 6", xCenter, 370 );
        g2d.setColor( OUTLINE_COLOR );
        drawPin( g2d, 1, Color.WHITE );
        drawPin( g2d, 2, Color.BLACK );
        drawPin( g2d, 3, Color.RED );
        drawPin( g2d, 4, GREEN );
        drawPin( g2d, 5, Color.YELLOW );
        drawPin( g2d, 6, BLUE );
        }
    }
